@@ -1,6 +1,6 @@
 package Pcore::Util::UUID;
 
-use Pcore -export => { ALL => [qw[is_uuid_str uuid_bin uuid_str uuid_hex create_uuid create_uuid_from_bin create_uuid_from_str create_uuid_from_hex]] };
+use Pcore -export => { ALL => [qw[looks_like_uuid uuid_bin uuid_str uuid_hex create_uuid create_uuid_from_bin create_uuid_from_str create_uuid_from_hex]] };
 use Pcore::Util::UUID::Obj;
 use Data::UUID qw[];    ## no critic qw[Modules::ProhibitEvilModules]
 
@@ -15,7 +15,7 @@ our $UUID = Data::UUID->new;
 *uuid_str = \&str;
 *uuid_hex = \&hex;
 
-sub is_uuid_str ($str) {
+sub looks_like_uuid ($str) {
     return $str =~ /\A[[:xdigit:]]{8}-[[:xdigit:]]{4}-[[:xdigit:]]{4}-[[:xdigit:]]{4}-[[:xdigit:]]{12}\z/sm;
 }
 
@@ -40,11 +40,11 @@ sub bin {
 }
 
 sub str {
-    return $UUID->create_str;
+    return lc $UUID->create_str;
 }
 
 sub hex {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
-    return $UUID->create_hex;
+    return lc $UUID->create_hex;
 }
 
 1;
